<?php
/**
 * Template functions for Grimlock for WooCommerce Subscriptions
 *
 * @package grimlock-woocommerce-subscriptions/inc
 */

/**
 * Display access length.
 *
 * @param $post_id int The ID for the current post
 *
 * @since 1.0.0
 */
function grimlock_woocommerce_subscriptions_access_length( $post_id = 0 ) {
	$access_length = get_post_meta( $post_id, '_access_length', true );
	if ( ! empty( $access_length ) ) :
		printf( esc_html__( '%s access', 'grimlock-woocommerce-subscriptions' ), $access_length );
	else :
		esc_html_e( 'Unlimited access', 'grimlock-woocommerce-subscriptions' );
	endif;
}

/**
 * Prints HTML for the product template
 *
 * @param array $args The array of arguments from the component
 */
function grimlock_woocommerce_subscriptions_product_template( $args ) {
	?>
	<div class="card product__card card--subscription-plan">

		<?php
		/**
		 * Hook: grimlock_woocommerce_subscriptions_product_card
		 *
		 * @hooked grimlock_woocommerce_subscriptions_product_header  - 10
		 * @hooked grimlock_woocommerce_subscriptions_product_content - 20
		 * @hooked grimlock_woocommerce_subscriptions_product_footer  - 30
		 */
		do_action( 'grimlock_woocommerce_subscriptions_product_card', $args ); ?>

	</div> <!-- .card -->
	<?php
}

/**
 * Prints HTML for the product header
 *
 * @param array $args The array of arguments from the component
 */
function grimlock_woocommerce_subscriptions_product_header( $args ) {
	?>
	<header class="card-header card--subscription-plan__header entry-header clearfix">
		<?php
		/**
		 * Hook: grimlock_woocommerce_subscriptions_product_header
		 *
		 * @hooked grimlock_woocommerce_subscriptions_product_title   - 10
		 * @hooked grimlock_woocommerce_subscriptions_product_excerpt - 20
		 * @hooked grimlock_woocommerce_subscriptions_product_price   - 30
		 */
		do_action( 'grimlock_woocommerce_subscriptions_product_header', $args ); ?>
	</header> <!-- .entry-header -->
	<?php
}

/**
 * Prints HTML for the product title
 *
 * @param array $args The array of arguments from the component
 */
function grimlock_woocommerce_subscriptions_product_title() {
	the_title( '<h2 class="entry-title card--subscription-plan__title">', '</h2>' );
}

/**
 * Prints HTML for the product excerpt
 */
function grimlock_woocommerce_subscriptions_product_excerpt() {
	if ( has_excerpt() ): ?>
		<div class="card--subscription-plan__excerpt">
			<?php the_excerpt(); ?>
		</div> <!-- .card--subscription-plan__excerpt -->
	<?php endif;
}

/**
 * Prints HTML for the product price
 */
function grimlock_woocommerce_subscriptions_product_price() {
	if ( function_exists( 'woocommerce_template_loop_price' ) ) : ?>
		<div class="card--subscription-plan__price"><?php woocommerce_template_loop_price(); ?></div>
	<?php endif;
}

/**
 * Prints HTML for the product content
 *
 * @param array $args The array of arguments from the component
 */
function grimlock_woocommerce_subscriptions_product_content( $args ) {
	if ( ! empty( $args['post_content_displayed'] ) ) : ?>
		<div class="card--subscription-plan__content entry-content">
			<?php the_content(); ?>
		</div> <!-- .card--subscription-plan__content -->
	<?php endif;
}

/**
 * Prints HTML for the product footer
 *
 * @param array $args The array of arguments from the component
 */
function grimlock_woocommerce_subscriptions_product_footer( $args ) {
	?>
	<footer class="card-footer card--subscription-plan__footer">
		<?php
		/**
		 * Hook: grimlock_woocommerce_subscriptions_product_footer
		 *
		 * @hooked grimlock_woocommerce_subscriptions_product_add_to_cart - 10
		 */
		do_action( 'grimlock_woocommerce_subscriptions_product_footer', $args ); ?>
	</footer> <!-- .card--subscription-plan__footer -->
	<?php
}

/**
 * Prints HTML for the product add to cart
 */
function grimlock_woocommerce_subscriptions_product_add_to_cart() {
	if ( function_exists( 'woocommerce_template_loop_add_to_cart' ) ) : ?>
		<div class="card--subscription-plan__sign-up">
			<?php woocommerce_template_loop_add_to_cart(); ?>
		</div> <!-- .card--subscription-plan__sign-up -->
	<?php
	endif;
}
