<?php

/**
 * Grimlock_WooCommerce_Subscriptions_Products_Section_Widget_Fields Class
 *
 * @author  Themosaurus
 * @since   1.0.0
 * @package  grimlock
 */
class Grimlock_WooCommerce_Subscriptions_Products_Section_Widget_Fields extends Grimlock_Query_Section_Widget_Fields {

	/**
	 * Setup class
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct( $id_base = 'grimlock_woocommerce_subscriptions_products_section_widget' ) {
		parent::__construct( $id_base );

		// Query tab
		remove_action( "{$this->id_base}_query_tab",   array( $this, 'add_post_type_field'           ), 100 );

		remove_action( "{$this->id_base}_style_tab",   array( $this, 'add_button_format_field'       ), 220 );
		remove_action( "{$this->id_base}_style_tab",   array( $this, 'add_button_size_field'         ), 230 );
	}

	/**
	 * Add a select to set the items layout
	 *
	 * @param array $instance
	 * @param WP_Widget $widget
	 * @since 1.0.0
	 */
	public function add_posts_layout_field( $instance, $widget ) {
		$args = array(
			'id'      => $widget->get_field_id( 'posts_layout' ),
			'name'    => $widget->get_field_name( 'posts_layout' ),
			'label'   => esc_html__( 'Layout:', 'grimlock-woocommerce-subscriptions' ),
			'value'   => $instance['posts_layout'],
			'choices' => array(
				'12-cols-classic'      => GRIMLOCK_PLUGIN_DIR_URL . 'assets/images/posts-12-cols-classic.png',
				'6-6-cols-classic'     => GRIMLOCK_PLUGIN_DIR_URL . 'assets/images/posts-6-6-cols-classic.png',
				'4-4-4-cols-classic'   => GRIMLOCK_PLUGIN_DIR_URL . 'assets/images/posts-4-4-4-cols-classic.png',
				'3-3-3-3-cols-classic' => GRIMLOCK_PLUGIN_DIR_URL . 'assets/images/posts-3-3-3-3-cols-classic.png',
			),
		);

		$this->radio_image( apply_filters( "{$this->id_base}_posts_layout_field_args", $args, $instance ) );
	}

	/**
	 * Add a select to set the taxonomies for the query
	 *
	 * @param array $instance
	 * @param WP_Widget $widget
	 * @since 1.0.0
	 */
	public function add_taxonomies_field( $instance, $widget ) {
		$taxonomies_choices = array();
		$terms              = get_terms( array( 'taxonomy' => 'product_cat' ) );
		$terms_choices      = array();

		if ( ! is_wp_error( $terms ) ) {
			foreach ( $terms as $term ) {
				$terms_choices['product_cat|' . $term->slug] = $term->name;
			}
		}

		$taxonomies_choices['product_cat'] = array(
			'label'      => esc_html__( 'Categories', 'grimlock-woocommerce-subscriptions' ),
			'subchoices' => $terms_choices,
		);

		$args = array(
			'id'       => $widget->get_field_id( 'taxonomies' ),
			'name'     => $widget->get_field_name( 'taxonomies' ),
			'label'    => esc_html__( 'Taxonomies:', 'grimlock-woocommerce-subscriptions' ),
			'value'    => $instance['taxonomies'],
			'choices'  => $taxonomies_choices,
			'multiple' => true,
		);

		$this->select( apply_filters( "{$this->id_base}_taxonomies_field_args", $args, $instance ) );
	}

	/**
	 * Change the default settings for the widget
	 *
	 * @param array $defaults The default settings for the widget.
	 *
	 * @return array The updated default settings for the widget.
	 */
	public function change_defaults( $defaults ) {
		$defaults = parent::change_defaults( $defaults );

		return array_merge( $defaults, array(
			'title'               => esc_html__( 'Subscription Plans', 'grimlock-woocommerce-subscriptions' ),

			'posts_per_page'      => '3',
			'orderby'             => 'menu_order',
			'order'               => 'ASC',
		) );
	}

	/**
	 * @param $instance
	 *
	 * @return WP_Query
	 */
	public function make_query( $instance ) {
		$query_args = array(
			'post_type'      => 'product',
			'posts_per_page' => $instance['posts_per_page'],
			'orderby'        => $instance['orderby'],
			'order'          => $instance['order'],
			'tax_query'      => array(),
		);

		if ( ! empty( $instance['taxonomies'] ) ) {
			$taxonomies_terms = array();
			foreach ( $instance['taxonomies'] as $term ) {
				$taxonomy_term = explode( '|', $term, 2 );
				if ( ! isset( $taxonomies_terms[ $taxonomy_term[0] ] ) ) {
					$taxonomies_terms[ $taxonomy_term[0] ] = array();
				}
				$taxonomies_terms[ $taxonomy_term[0] ][] = $taxonomy_term[1];
			}

			$tax_query = array();
			foreach ( $taxonomies_terms as $taxonomy => $terms ) {
				$tax_query[] = array(
					'taxonomy' => $taxonomy,
					'field'    => 'slug',
					'terms'    => $terms
				);
			}

			$query_args['tax_query'] = $tax_query;
		}

		$hide_out_of_stock = get_option( 'woocommerce_hide_out_of_stock_items' );

		if ( 'yes' === $hide_out_of_stock ) {
			$query_args['tax_query'][] = array(
				'taxonomy' => 'product_visibility',
				'field'    => 'name',
				'terms'    => 'outofstock',
				'operator' => 'NOT IN',
			);
		}

		$query_args['meta_key'] = $instance['meta_key'];
		$meta_value_arg = empty( $instance['meta_value_num'] ) ? 'meta_value' : 'meta_value_num';
		$query_args[ $meta_value_arg ] = $instance['meta_value'];
		$query_args['meta_compare'] = $instance['meta_compare'];

		return new WP_Query( $query_args );
	}

	/**
	 * Get the widget classes
	 *
	 * @param array $instance Settings for the current widget instance.
	 *
	 * @return array The widget classes
	 */
	protected function get_classes( $instance ) {
		$classes   = array( $instance['classes'] );
		$classes[] = "grimlock-query-section--woocommerce-subscriptions";
		$title     = ! empty( $instance['title'] ) ? sanitize_title( $instance['title'] ) : '';

		if ( '' !== $title ) {
			$classes[] = "grimlock-query-section--{$title}";
		}

		return $classes;
	}
}

return new Grimlock_WooCommerce_Subscriptions_Products_Section_Widget_Fields();